# Version history

## 0.4.1

- Add `py.typed`.

## 0.4.0

- Change API names.

## 0.3.0

- Fix server shutdown.
- Allow component name from entry-point in config.
- Add `merge_config()`.
- Allow adding components from config dictionary.
- Add `get_resource()` timeout parameter.
- Make `self.done()` optional.
- Add logging.
- Add FastAPIComponent.

## 0.2.0

## 0.1.0
